@@ -44,6 +44,7 @@ mnodeA :: Node t => String -> String -> t -> Element
 mnodeA s v = add_attr (Attr (QName "val" Nothing (Just "m")) v) . mnode s
 
 str :: [Element] -> String -> Element
+str []    s = mnode "r" [ mnode "t" s ]
 str props s = mnode "r" [ mnode "rPr" props
                         , mnode "t" s ]
 
@@ -67,16 +68,22 @@ showFraction props ft x y =
     where x' = showExp props x
           y' = showExp props y
 
+maximum' :: [Int] -> Int
+maximum' [] = 0
+maximum' xs = maximum xs
+
 makeArray :: [Element] -> [Alignment] -> [ArrayLine] -> Element
 makeArray props as rs = mnode "m" $ mProps : map toMr rs
   where mProps = mnode "mPr"
                   [ mnodeA "baseJc" "center" ()
-                  , mnodeA "plcHide" "on" ()
+                  , mnodeA "plcHide" "1" ()
                   , mnode "mcs" $ map toMc as' ]
-        as'    = take (length rs) $ as ++ cycle [AlignDefault]
+        as'    = take (maximum' $ map length rs) $ as ++ cycle [AlignDefault]
         toMr r = mnode "mr" $ map (mnode "e" . concatMap (showExp props)) r
         toMc a = mnode "mc" $ mnode "mcPr"
-                            $ mnodeA "mcJc" (toAlign a) ()
+                            [ mnodeA "mcJc" (toAlign a) ()
+                            , mnodeA "count" "1" ()
+                            ]
         toAlign AlignLeft    = "left"
         toAlign AlignRight   = "right"
         toAlign AlignCenter  = "center"
@@ -172,8 +179,10 @@ showExp props e =
                                         mnodeA "pos" "top" ()
                                     , mnode "e" $ showExp props x ]]
    EOver _ x (ESymbol Accent y) ->
-                       [mnode "acc" [ mnode "accPr" $
-                                        mnodeA "chr" y ()
+                       [mnode "groupChr" [ mnode "groupChrPr"
+                                           [ mnodeA "chr" y ()
+                                           , mnodeA "pos" "top" ()
+                                           , mnodeA "vertJc" "bot" () ]
                                     , mnode "e" $ showExp props x ]]
    ESub x y         -> [mnode "sSub" [ mnode "e" $ showExp props x
                                      , mnode "sub" $ showExp props y]]
@@ -186,14 +195,12 @@ showExp props e =
                                        , mnode "lim" $ showExp props y]]
    EOver _ x y   -> [mnode "limUpp" [ mnode "e" $ showExp props x
                                        , mnode "lim" $ showExp props y]]
-   EUnderover c x y z -> showExp props (EUnder c x (EOver c y z))
-   ESqrt x       -> [mnode "rad" [ mnode "radPr" $ mnodeA "degHide" "on" ()
+   EUnderover c x y z -> showExp props (EUnder c (EOver c x z) y)
+   ESqrt x       -> [mnode "rad" [ mnode "radPr" $ mnodeA "degHide" "1" ()
                                       , mnode "deg" ()
                                       , mnode "e" $ showExp props x]]
-   ERoot i x     -> [mnode "rad" [ mnode "radPr" $
-                                   mnodeA "degHide" "on" ()
-                                , mnode "deg" $ showExp props i
-                                , mnode "e" $ showExp props x]]
+   ERoot i x     -> [mnode "rad" [ mnode "deg" $ showExp props i
+                                 , mnode "e" $ showExp props x]]
    EFraction ft x y -> [showFraction props ft x y]
    EPhantom x       -> [mnode "phant" [ mnode "phantPr"
                                             [ mnodeA "show" "0" () ]
@@ -217,11 +224,11 @@ makeNary props t s y z w =
                  [ mnodeA "chr" s ()
                  , mnodeA "limLoc" t ()
                  , mnodeA "subHide"
-                    (if y == EGrouped [] then "on" else "off") ()
+                    (if y == EGrouped [] then "1" else "0") ()
                  , mnodeA "supHide"
-                    (if z == EGrouped [] then "on" else "off") ()
+                    (if z == EGrouped [] then "1" else "0") ()
                  ]
-               , mnode "e" $ showExp props w
                , mnode "sub" $ showExp props y
-               , mnode "sup" $ showExp props z ]
+               , mnode "sup" $ showExp props z
+               , mnode "e" $ showExp props w ]
 
